==> nextcloud-18.0.7.tgz: nextcloud/apps/firstrunwizard/l10n/zh_CN.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "Copy to clipboard" : "复制到剪贴板",
    "Copied!" : "已复制！",
    "Not supported!" : "不支持！",
    "Press ⌘-C to copy." : "按 ⌘-C 复制。",
    "Press Ctrl-C to copy." : "按 Ctrl-C 复制。",
    "First run wizard" : "首次运行显示向导",
    "Add your profile information! For example your email is needed to reset your password." : "请添加您的个人信息！比如您的邮件被用来重置您的密码。",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "添加您的个人资料信息！设置个人资料图片和全名，以便在所有功能中轻松识别。",
    "Add your profile information! Set a full name for easier recognition across all features." : "添加您的个人资料信息！设置全名，以便在所有功能中轻松识别。",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "添加您的个人资料信息！设置个人资料图片，以便在所有功能中轻松识别。",
    "App recommendation: Nextcloud Calendar" : "应用推荐：Nextcloud 日历",
    "Schedule work & meetings, synced with all your devices." : "安排工作和会议，与您的所有设备同步。",
    "App recommendation: Nextcloud Contacts" : "应用推荐：Nextcloud 联系人",
    "Keep your colleagues and friends in one place without leaking their private info." : "将您同事朋友的信息保存在一个地方而不会泄露他们的隐私。",
    "App recommendation: Nextcloud Mail" : "应用推荐：Nextcloud 邮件",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "简单的电子邮件应用，与文件、联系人和日历应用集成。",
    "App recommendation: Tasks" : "应用推荐：任务",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "将各种设备的任务与 Nextcloud 同步，然后在线进行编辑。",
    "App recommendation: Deck" : "应用推荐：看板",
    "Kanban style organization for personal planning and team projects." : "看板式的组织个人计划和团队项目。",
    "App recommendation: Notes" : "应用推荐：笔记",
    "Distraction-free notes and writing." : "无干扰的笔记和写作。",
    "App recommendation: Social" : "应用推荐：社交",
    "Nextcloud becomes part of the federated social networks." : "Nextcloud 已经成为了联合社交网络的一部分。",
    "App recommendation: Group folders" : "应用推荐：群组文件夹",
    "Admin-configured folders shared by everyone in a group." : "由管理员配置的被用户组所有成员共享的文件夹。",
    "About" : "关于",
    "A welcome and introduction wizard for Nextcloud" : "Nextcloud 的欢迎和介绍向导",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "此应用在用户初次登录Nextcloud时启用一个弹窗。此弹窗欢迎新用户来到Nextcloud，包含标准桌面客户端，Android应用和iOS应用的链接。这个窗口也会显示从WebDAV访问Nextcloud的链接。在任何时间，初次运行向导都能通过 设置 目录上的\"关于\"链接再次打开。\n初次运行向导可以定制以满足某些设计需求，或修改链接和消息。可以很容易地按主题设置文档来创建合适的主题，以及改变向导的外观。更多信息请参见初次运行向导文档以及主题设置文档。",
    "Start using Nextcloud" : "开始使用 Nextcloud",
    "Extend your cloud" : "扩展您的云",
    "Find more than 100 apps in the Nextcloud app store to customize your cloud:" : "您可以在 Nextcloud 的应用中心中找到超过 100 个自定义应用：",
    "Groupware apps like Calendar, Contacts, Mail" : "群组应用如日历，联系人，邮件",
    "Communication with Nextcloud Talk" : "使用 Nextcloud 通话应用沟通",
    "Collaboration apps for document editing" : "用于文档编辑的协作应用",
    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "安全与认证特性如两步验证，单点登录和勒索病毒保护",
    "Many others like a music player, a password manager, a kanban app, a download manager or a markdown editor" : "还有很多应用如音乐播放器，密码管理器，看板 app，下载管理器和 markdown 编辑器",
    "Browse the app store" : "浏览应用商店",
    "Stay in sync" : "保持同步",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud让您可以随时随地访问您的文件。",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "我们在所有主流平台上提供免费且易用的桌面和移动客户端！",
    "Get the apps to sync your files" : "安装应用进行文件同步",
    "Desktop client" : "桌面客户端",
    "Android app" : "安卓应用",
    "iOS app" : "iOS 应用",
    "Connect your desktop apps to %s" : "使用桌面应用连接到 %s",
    "Connect your calendar" : "连接您的日历",
    "Connect your contacts" : "连接您的联系人",
    "Access files via WebDAV" : "通过 WebDAV 访问文件",
    "Download macOS/iOS configuration profile" : "下载 macOS/iOS 配置模板",
    "Get help" : "获取帮助",
    "Get more information" : "获取更多信息",
    "The Nextcloud documentation for home users:" : "适用于家庭用户的 Nextcloud 文档：",
    "User manual" : "用户手册",
    "Admin manual" : "管理员手册",
    "Developer manual" : "开发者手册",
    "You can also ask for help in our community support channels:" : "您也可以在我们的社区支持频道获取帮助：",
    "the Nextcloud forums" : "Nextcloud 论坛",
    "the Nextcloud IRC chat channel on freenode.net" : "freenode.net 上的 Nextcloud IRC 聊天频道",
    "Start contributing" : "开始贡献",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "您想改进 Nextcloud？您发现了一个问题？您想帮助翻译，促进 Nextcloud 或为其编写文档？",
    "Become part of the Community" : "成为社区的一分子",
    "Enterprise support" : "企业级技术支持",
    "If you run Nextcloud in a mission critical environment with large numbers of users and big amounts of data and need the certainty of support from the experts behind the Nextcloud technology, an Enterprise Subscription from Nextcloud is available with email and phone support." : "如果您在拥有海量用户和数据的关键任务环境中运行 Nextcloud，需要 Nextcloud 技术背后的专家提供确定的支持，您可以购买 Nextcloud 的企业级订阅，享受电子邮件和电话支持。",
    "Get enterprise support" : "获取企业级技术支持",
    "A safe home for all your data" : "给您所有数据一个安全的家",
    "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "Nextcloud 将您的数据置于您的掌控之中。在您公司、家中、我们的一个供应商或您了解的数据中心里的服务器上保存您的文档、日历、联系人以及照片。",
    "Host your data and files where you decide" : "把数据和文件保管在您想要的地方",
    "Open Standards and Interoperability" : "开放标准和互操作性",
    "100%% Open Source & community-focused" : "100 %% 开源，专注于为社区用户服务",
    "Learn more about %s" : "了解更多关于 %s 的详情",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "走到哪里，文件跟到哪里！ %s 免费客户端支持电脑手机的各大主流平台",
    "Set up sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "为同步客户端设置一个<a href=\"%s\">应用密码</a>，这样设备丢失的时候你就可确保撤销访问权限了。",
    "Connect other apps to %s" : "连接其它应用到 %s",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "除了 移动应用程序 和 桌面客户端 以外，您还可以将支持 WebDAV / CalDAV / CardDAV 协议的任何其他软件连接到 %s。",
    "Server address" : "服务器地址",
    "Use this link to connect your apps and desktop client to this server:" : "使用此链接将您的应用和桌面客户端连接到此服务器：",
    "Copy link" : "复制链接",
    "Previous" : "上一个",
    "Next" : "下一个",
    "App recommendation: Nextcloud Talk" : "应用推荐：Nextcloud 通话",
    "Screensharing, online meetings and web conferencing – on desktop and with mobile apps." : "屏幕共享、线上见面和网络会议 - 使用桌面电脑及移动应用。",
    "Setup sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "为同步客户端设置一个<a href=\"%s\">应用密码</a>，这样设备丢失的时候你就可确保撤销访问权限了。",
    "Besides the sync clients you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "除了 同步客户端，您还可以将支持 WebDAV / CalDAV / CardDAV 协议的任何其他软件连接到 %s。"
},
"nplurals=1; plural=0;");

==> nextcloud-18.0.9.tgz: nextcloud/apps/firstrunwizard/l10n/zh_CN.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "Copy to clipboard" : "复制到剪贴板",
    "Copied!" : "已复制！",
    "Not supported!" : "不支持！",
    "Press ⌘-C to copy." : "按 ⌘-C 复制。",
    "Press Ctrl-C to copy." : "按 Ctrl-C 复制。",
    "First run wizard" : "首次运行显示向导",
    "Add your profile information! For example your email is needed to reset your password." : "请添加您的个人信息！比如您的邮件被用来重置您的密码。",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "添加您的个人资料信息！设置个人资料图片和全名，以便在所有功能中轻松识别。",
    "Add your profile information! Set a full name for easier recognition across all features." : "添加您的个人资料信息！设置全名，以便在所有功能中轻松识别。",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "添加您的个人资料信息！设置个人资料图片，以便在所有功能中轻松识别。",
    "App recommendation: Nextcloud Calendar" : "应用推荐：Nextcloud 日历",
    "Schedule work & meetings, synced with all your devices." : "安排工作和会议，与您的所有设备同步。",
    "App recommendation: Nextcloud Contacts" : "应用推荐：Nextcloud 联系人",
    "Keep your colleagues and friends in one place without leaking their private info." : "将您同事朋友的信息保存在一个地方而不会泄露他们的隐私。",
    "App recommendation: Nextcloud Mail" : "应用推荐：Nextcloud 邮件",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "简单的电子邮件应用，与文件、联系人和日历应用集成。",
    "App recommendation: Tasks" : "应用推荐：任务",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "将各种设备的任务与 Nextcloud 同步，然后在线进行编辑。",
    "App recommendation: Deck" : "应用推荐：看板",
    "Kanban style organization for personal planning and team projects." : "看板式的组织个人计划和团队项目。",
    "App recommendation: Notes" : "应用推荐：笔记",
    "Distraction-free notes and writing." : "无干扰的笔记和写作。",
    "App recommendation: Social" : "应用推荐：社交",
    "Nextcloud becomes part of the federated social networks." : "Nextcloud 已经成为了联合社交网络的一部分。",
    "App recommendation: Group folders" : "应用推荐：群组文件夹",
    "Admin-configured folders shared by everyone in a group." : "由管理员配置的被用户组所有成员共享的文件夹。",
    "About" : "关于",
    "A welcome and introduction wizard for Nextcloud" : "Nextcloud 的欢迎和介绍向导",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "此应用在用户初次登录Nextcloud时启用一个弹窗。此弹窗欢迎新用户来到Nextcloud，包含标准桌面客户端，Android应用和iOS应用的链接。这个窗口也会显示从WebDAV访问Nextcloud的链接。在任何时间，初次运行向导都能通过 设置 目录上的\"关于\"链接再次打开。\n初次运行向导可以定制以满足某些设计需求，或修改链接和消息。可以很容易地按主题设置文档来创建合适的主题，以及改变向导的外观。更多信息请参见初次运行向导文档以及主题设置文档。",
    "Start using Nextcloud" : "开始使用 Nextcloud",
    "Extend your cloud" : "扩展您的云",
    "Find more than 100 apps in the Nextcloud app store to customize your cloud:" : "您可以在 Nextcloud 的应用中心中找到超过 100 个自定义应用：",
    "Groupware apps like Calendar, Contacts, Mail" : "群组应用如日历，联系人，邮件",
    "Communication with Nextcloud Talk" : "使用 Nextcloud 通话应用沟通",
    "Collaboration apps for document editing" : "用于文档编辑的协作应用",
    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "安全与认证特性如两步验证，单点登录和勒索病毒保护",
    "Many others like a music player, a password manager, a kanban app, a download manager or a markdown editor" : "还有很多应用如音乐播放器，密码管理器，看板 app，下载管理器和 markdown 编辑器",
    "Browse the app store" : "浏览应用商店",
    "Stay in sync" : "保持同步",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud让您可以随时随地访问您的文件。",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "我们在所有主流平台上提供免费且易用的桌面和移动客户端！",
    "Get the apps to sync your files" : "安装应用进行文件同步",
    "Desktop client" : "桌面客户端",
    "Android app" : "安卓应用",
    "iOS app" : "iOS 应用",
    "Connect your desktop apps to %s" : "使用桌面应用连接到 %s",
    "Connect your calendar" : "连接您的日历",
    "Connect your contacts" : "连接您的联系人",
    "Access files via WebDAV" : "通过 WebDAV 访问文件",
    "Download macOS/iOS configuration profile" : "下载 macOS/iOS 配置模板",
    "Get help" : "获取帮助",
    "Get more information" : "获取更多信息",
    "The Nextcloud documentation for home users:" : "适用于家庭用户的 Nextcloud 文档：",
    "User manual" : "用户手册",
    "Admin manual" : "管理员手册",
    "Developer manual" : "开发者手册",
    "You can also ask for help in our community support channels:" : "您也可以在我们的社区支持频道获取帮助：",
    "the Nextcloud forums" : "Nextcloud 论坛",
    "the Nextcloud IRC chat channel on freenode.net" : "freenode.net 上的 Nextcloud IRC 聊天频道",
    "Start contributing" : "开始贡献",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "您想改进 Nextcloud？您发现了一个问题？您想帮助翻译，促进 Nextcloud 或为其编写文档？",
    "Become part of the Community" : "成为社区的一分子",
    "Enterprise support" : "企业级技术支持",
    "If you run Nextcloud in a mission critical environment with large numbers of users and big amounts of data and need the certainty of support from the experts behind the Nextcloud technology, an Enterprise Subscription from Nextcloud is available with email and phone support." : "如果您在拥有海量用户和数据的关键任务环境中运行 Nextcloud，需要 Nextcloud 技术背后的专家提供确定的支持，您可以购买 Nextcloud 的企业级订阅，享受电子邮件和电话支持。",
    "Get enterprise support" : "获取企业级技术支持",
    "A safe home for all your data" : "给您所有数据一个安全的家",
    "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "Nextcloud 将您的数据置于您的掌控之中。在您公司、家中、我们的一个供应商或您了解的数据中心里的服务器上保存您的文档、日历、联系人以及照片。",
    "Host your data and files where you decide" : "把数据和文件保管在您想要的地方",
    "Open Standards and Interoperability" : "开放标准和互操作性",
    "100%% Open Source & community-focused" : "100 %% 开源，专注于为社区用户服务",
    "Learn more about %s" : "了解更多关于 %s 的详情",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "走到哪里，文件跟到哪里！ %s 免费客户端支持电脑手机的各大主流平台",
    "Set up sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "为同步客户端设置一个<a href=\"%s\">应用密码</a>，这样设备丢失的时候你就可确保撤销访问权限了。",
    "Connect other apps to %s" : "连接其它应用到 %s",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "除了 移动应用程序 和 桌面客户端 以外，您还可以将支持 WebDAV / CalDAV / CardDAV 协议的任何其他软件连接到 %s。",
    "Server address" : "服务器地址",
    "Use this link to connect your apps and desktop client to this server:" : "使用此链接将您的应用和桌面客户端连接到此服务器：",
    "Copy link" : "复制链接",
    "App recommendation: Nextcloud Talk" : "应用推荐：Nextcloud 通话",
    "Screensharing, online meetings and web conferencing – on desktop and with mobile apps." : "屏幕共享、线上见面和网络会议 - 使用桌面电脑及移动应用。",
    "Setup sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "为同步客户端设置一个<a href=\"%s\">应用密码</a>，这样设备丢失的时候你就可确保撤销访问权限了。",
    "Besides the sync clients you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "除了 同步客户端，您还可以将支持 WebDAV / CalDAV / CardDAV 协议的任何其他软件连接到 %s。",
    "Previous" : "上一个",
    "Next" : "下一个"
},
"nplurals=1; plural=0;");
